@@ -9,7 +9,8 @@ from firexapp.submit.tracking_service import TrackingService
 from firexapp.common import qualify_firex_bin, select_env_vars
 from firexapp.submit.console import setup_console_logging
 
-from firex_blaze.blaze_helper import get_blaze_dir
+from firex_blaze.fast_blaze_helper import get_blaze_dir
+from firexapp.discovery import PkgVersionInfo
 
 
 logger = setup_console_logging(__name__)
@@ -39,11 +40,11 @@ class FireXBlazeLauncher(TrackingService):
         arg_parser.add_argument('--blaze_kafka_topic',
                                 help="Topic used for Blaze's Kafka bus",
                                 default=None)
+
         arg_parser.add_argument('--blaze_bootstrap_servers',
                                 help='Comma separated list of Kafka bootrap servers.',
                                 default=None)
 
-
     @classmethod
     def _create_blaze_command(cls, uid, args, broker_recv_ready_file):
         return [qualify_firex_bin("firex_blaze"),
@@ -67,7 +68,7 @@ class FireXBlazeLauncher(TrackingService):
             self.is_ready_for_tasks = True
             return {}
 
-        blaze_debug_dir = get_blaze_dir(uid.logs_dir, self.instance_name)
+        blaze_debug_dir = get_blaze_dir(uid.logs_dir)
         os.makedirs(blaze_debug_dir, exist_ok=True)
         self.broker_recv_ready_file = os.path.join(blaze_debug_dir, 'blaze_celery_recvr_ready')
         self.stdout_file = os.path.join(blaze_debug_dir, 'blaze.stdout')
@@ -94,3 +95,13 @@ class FireXBlazeLauncher(TrackingService):
                 logger.debug("Blaze up after %.2f s" % (time.time() - self.start_time))
 
         return self.is_ready_for_tasks
+
+    def get_version(self):
+        import firex_blaze
+        return firex_blaze.__version__
+
+    def get_pkg_version_info(self) -> PkgVersionInfo:
+        import firex_blaze
+        return PkgVersionInfo(pkg=firex_blaze.__package__,
+                              version=firex_blaze.__version__,
+                              commit=firex_blaze._version.get_versions()['full-revisionid'])
\ No newline at end of file
